=========
*pytconf*
=========

.. image:: https://img.shields.io/pypi/v/pytconf

.. image:: https://img.shields.io/github/license/veltzer/pytconf

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pytconf

author: Mark Veltzer

version: 0.0.76


